# reconfigurator

[![Downloads](https://static.pepy.tech/badge/reconfigurator)](https://pepy.tech/project/reconfigurator)

This package provides tools for reconfiguring files, markdown for sampling and generating configuration files. 


Please see our [Documentation](https://reconfigurator.readthedocs.io/en/latest/introduction.html), 
[Github source code](https://github.com/jaredjbeard/reconfigurator), 
and install from [PyPI](https://pypi.org/project/reconfigurator/)

Citation
--------
If you are using this in your work, please cite as

```
@misc{beard2022irl_gym,
    author = {Beard, Jared J.},
    title = {reconfigurator: A tool for configuration files},
    year = {2022},
    publisher = {GitHub},
    journal = {GitHub repository},
    howpublished = {\url{https://github.com/jaredjbeard/reconfigurator}},
}
```
